import{a4 as n,cU as u,F as m,a2 as d,j as s,eQ as i,eR as j}from"./index-C88DWJny.js";import{U as x}from"./UsedByItem-CNDK_7QF.js";import{E as p}from"./ExpandableList-DztXpwLZ.js";const U=({entityType:e,usedBy:a})=>{if(!a)return null;const{project:o}=n(),t=u(e,a),c=e==="volume"?"Custom volume":m(e.replaceAll("-"," ")),l=d(c,t.length);return s.jsxs("tr",{className:"used-by-row",children:[s.jsxs("th",{className:"u-text--muted used-by-row-header",children:[s.jsx(i,{type:e,className:"icon"}),l," (",t.length,")"]}),s.jsx("td",{children:s.jsx(p,{items:t.map(r=>s.jsx(x,{item:r,activeProject:o?.name||"default",type:e,to:j(r,e)},`${r.name}-${r.project}-${r.target??""}`))})})]})};export{U};
