import{j as e,L as s,R as o,d as r}from"./index-C88DWJny.js";const c=({address:n,instanceName:t,projectName:i})=>e.jsxs("div",{className:"instance-ip-edit-content",children:[e.jsx("div",{className:"u-truncate instance-ip-edit-address",title:n,children:n}),e.jsx(s,{to:`${o}/ui/project/${encodeURIComponent(i)}/instance/${encodeURIComponent(t)}/configuration/network`,rel:"noopener noreferrer",className:"p-button-base instance-ip-edit-link is-dense",type:"button",title:`Edit network configuration for instance ${t}`,children:e.jsx(r.Icon,{name:"edit"})})]});export{c as I};
