import{a as t,aP as u,q as s}from"./index-C88DWJny.js";import{a as o,b as c}from"./network-acls-DoFbevfN.js";const i=(e,r)=>{const{isFineGrained:n}=t();return u({queryKey:[s.projects,e,s.networkAcls],queryFn:async()=>o(e,n),enabled:n!==null})},A=(e,r,n)=>{const{isFineGrained:a}=t();return u({queryKey:[s.projects,r,s.networkAcls,e],queryFn:async()=>c(e,r,a),enabled:a!==null})};export{i as a,A as u};
