import{j as r,d as p}from"./index-C88DWJny.js";const h=({onChange:s,value:o,disabled:a,className:t})=>{const e=n=>{s(n.toLowerCase())};return r.jsx("div",{className:"permission-groups-filter",children:r.jsx(p.SearchBox,{id:"search-groups",label:"Search groups",name:"search-groups",type:"text",onSearch:e,onChange:e,value:o,placeholder:"Search groups",disabled:a,className:t})})};export{h as P};
