import{d as o,j as e}from"./index-C88DWJny.js";const i=({children:t,className:s})=>{const r=o.useNotify();return e.jsx(o.ScrollableContainer,{dependencies:[r.notification],belowIds:["status-bar","form-footer"],className:s,children:t})};export{i as S};
