import{d as s,r as c,j as e,c as o,a as d,i as p,N as h,R as x,e as j}from"./index-C88DWJny.js";const m=()=>{const i=s.useNotify(),[t,n]=c.useState(""),a=()=>{const l=t.trim().split(/\r?\n|\r|\n/g).at(-1)??"";o(l).then(()=>{location.reload()}).catch(r=>i.failure("Error using token",r))};return e.jsxs(s.Form,{children:[e.jsx(s.Textarea,{id:"token",name:"token",label:"Paste the token from the previous step",placeholder:"Paste your token here",rows:3,onChange:l=>{n(l.target.value)}}),e.jsx(s.Button,{appearance:"positive",disabled:t.length<1,type:"button",onClick:a,children:"Import"})]})},_=()=>{const{isAuthenticated:i,isAuthLoading:t,authMethod:n}=d(),a=s.useNotify();return t?e.jsx(s.Spinner,{className:"u-loader",text:"Loading...",isMainComponent:!0}):i&&p(n)?e.jsx(h,{to:`${x}/ui`,replace:!0}):e.jsxs(s.CustomLayout,{mainClassName:"certificate-generate",header:e.jsx("div",{className:"p-panel__header is-sticky",children:e.jsx("h1",{className:"p-panel__title",children:"Add existing certificate"})}),children:[a.notification?e.jsx(j,{}):e.jsx(s.Row,{children:e.jsxs(s.Notification,{severity:"caution",children:["A client certificate must be present and selected in your browser.",e.jsx("br",{})]})}),e.jsx(s.Row,{className:"u-no-margin--left",children:e.jsx(s.Col,{size:12,children:e.jsxs("ol",{className:"p-stepped-list--detailed",children:[e.jsx("li",{className:"p-stepped-list__item",children:e.jsxs(s.Row,{children:[e.jsx(s.Col,{size:3,children:e.jsx("h2",{className:"p-stepped-list__title p-heading--5",children:"Create token"})}),e.jsx(s.Col,{size:6,children:e.jsxs("div",{className:"p-stepped-list__content",children:[e.jsx("p",{children:"Generate a token on the command line"}),e.jsx("div",{className:"p-code-snippet",children:e.jsx("pre",{className:"p-code-snippet__block--icon",children:e.jsx("code",{children:"incus config trust add incus-ui"})})})]})})]})}),e.jsx("li",{className:"p-stepped-list__item",children:e.jsxs(s.Row,{children:[e.jsx(s.Col,{size:3,children:e.jsx("h2",{className:"p-stepped-list__title p-heading--5",children:"Import"})}),e.jsx(s.Col,{size:6,children:e.jsx("div",{className:"p-stepped-list__content",children:e.jsx(m,{})})})]})}),e.jsx("li",{className:"p-stepped-list__item u-no-margin--bottom",children:e.jsxs(s.Row,{children:[e.jsx(s.Col,{size:3,children:e.jsx("h2",{className:"p-stepped-list__title p-heading--5",children:"Done"})}),e.jsx(s.Col,{size:6,children:e.jsx("div",{className:"p-stepped-list__content",children:e.jsx("p",{children:"Enjoy Incus UI."})})})]})})]})})})]})};export{_ as default};
