import{a,x as n}from"./index-C88DWJny.js";const m=()=>{const{isFineGrained:e}=a();return{canDeleteImage:s=>n(e,"can_delete",s?.access_entitlements)}},r=()=>{const{isFineGrained:e}=a();return{canDeleteImageRegistry:t=>n(e,"can_delete",t?.access_entitlements),canEditImageRegistry:t=>n(e,"can_edit",t?.access_entitlements)}};export{r as a,m as u};
