import{j as t,d as s}from"./index-C88DWJny.js";const p=({title:a,controls:n,children:e,mainClassName:r,contentClassName:o})=>t.jsx(s.AppMain,{className:r,id:"main-content",children:t.jsx(s.Panel,{title:a,controls:n,wrapContent:!0,contentClassName:o,children:e})});export{p as B};
