import{a as r,aP as a,q as i}from"./index-C88DWJny.js";import{f as t,b as u,a as y}from"./image-registries-T9CKqPfx.js";const m=(e=!0)=>{const{isFineGrained:s}=r();return a({queryKey:[i.imageRegistries],queryFn:async()=>t(s),enabled:e&&s!==null})},o=(e,s=!0)=>{const{isFineGrained:n}=r();return a({queryKey:[i.imageRegistries,e],queryFn:async()=>u(e,n),enabled:s&&n!==null})},l=e=>{const{isFineGrained:s}=r();return a({queryKey:[i.imageRegistries,e,"images"],queryFn:async()=>y(e,s),enabled:s!==null})};export{o as a,l as b,m as u};
