import{j as o,P as j,o as s,R as m,eP as u,ab as x}from"./index-C88DWJny.js";import{a as d}from"./useImages-D7BEIPVo.js";import{P as h}from"./ProfileRichChip-BlhTHgMo.js";const v=({item:e,activeProject:a,type:n,to:r,projectLinkDetailPage:c="instances"})=>{const t=n==="image",{data:p=[]}=d(e.project||a,t),i=p.find(l=>l.fingerprint===e.name)?.properties?.description||e.name;return o.jsxs("div",{children:[e.project!==a&&o.jsxs(o.Fragment,{children:[o.jsx(j,{projectName:e.project,urlSuffix:`/${encodeURIComponent(c)}`})," ","/"," "]}),n==="snapshot"&&e.instance&&o.jsxs(o.Fragment,{children:[o.jsx(s,{type:"instance",value:e.instance,to:`${m}/ui/project/${encodeURIComponent(e.project)}/instance/${encodeURIComponent(e.instance)}`})," ","/"," "]}),n==="snapshot"&&e.volume&&o.jsxs(o.Fragment,{children:[o.jsx(s,{type:"volume",value:e.volume,to:u({name:e.volume,project:e.project,pool:e.pool,type:"custom",location:e.target??""})})," ","/"," "]}),n==="instance"&&o.jsx(x,{instanceName:e.name,projectName:e.project}),n==="profile"&&o.jsx(h,{profileName:e.name,projectName:e.project}),n!=="instance"&&n!=="profile"&&o.jsx(s,{type:n,value:i,to:r})]})};export{v as U};
