import{j as s,D as i,d as a}from"./index-C88DWJny.js";const o=({children:e,title:l,docPath:n})=>s.jsxs("div",{className:"help-link",children:[e,s.jsx(i,{docPath:n,title:l,className:"help-link-doc-link",children:s.jsx(a.Icon,{name:"help",className:"help-link-icon"})})]});export{o as H};
