define("vs/monaco.contribution-EcChJV6a",["require","exports","./editor.api-CalNCsUg"],(function(a,n,o){"use strict";class u{constructor(e,d,m){this._onDidChange=new o.Emitter,this._languageId=e,this.setDiagnosticsOptions(d),this.setModeConfiguration(m)}get onDidChange(){return this._onDidChange.event}get languageId(){return this._languageId}get modeConfiguration(){return this._modeConfiguration}get diagnosticsOptions(){return this._diagnosticsOptions}setDiagnosticsOptions(e){this._diagnosticsOptions=e||Object.create(null),this._onDidChange.fire(this)}setModeConfiguration(e){this._modeConfiguration=e||Object.create(null),this._onDidChange.fire(this)}}const g={validate:!0,allowComments:!0,schemas:[],enableSchemaRequest:!1,schemaRequest:"warning",schemaValidation:"warning",comments:"error",trailingCommas:"error"},c={documentFormattingEdits:!0,documentRangeFormattingEdits:!0,completionItems:!0,hovers:!0,documentSymbols:!0,tokens:!0,colors:!0,foldingRanges:!0,diagnostics:!0,selectionRanges:!0},s=new u("json",g,c),i=()=>r().then(t=>t.getWorker());function r(){return new Promise((t,e)=>a(["./jsonMode-DULH5oaX"],t,e))}o.languages.register({id:"json",extensions:[".json",".bowerrc",".jshintrc",".jscsrc",".eslintrc",".babelrc",".har"],aliases:["JSON","json"],mimetypes:["application/json"]}),o.languages.onLanguage("json",()=>{r().then(t=>t.setupMode(s))});const l=Object.freeze(Object.defineProperty({__proto__:null,getWorker:i,jsonDefaults:s},Symbol.toStringTag,{value:"Module"}));n.getWorker=i,n.jsonDefaults=s,n.monaco_contribution=l}));
