const t="user.ui.image_servers",a=e=>{if(!e)return[];try{const s=JSON.parse(e);return Array.isArray(s)?s.filter(r=>typeof r=="object"&&r!==null&&typeof r.url=="string").map(r=>({name:typeof r.name=="string"?r.name:"",url:r.url,protocol:"simplestreams"})):[]}catch{return[]}},n=e=>JSON.stringify(e);export{t as I,a as p,n as s};
