import{du as c,j as e,d as t,o as l}from"./index-C88DWJny.js";function u(){const{showModal:n,hideModal:a}=c();return i=>{const r=e.jsx(t.Modal,{close:a,title:"Bulk operation details",children:e.jsx(t.MainTable,{style:{width:"auto"},headers:[{content:"Item"},{content:"Details"}],rows:i.map(s=>{const o=s.status==="fulfilled";return{columns:[{content:e.jsx(l,{value:s.item.name,type:s.item.type,to:s.item.href})},{content:e.jsxs(e.Fragment,{children:[e.jsx(t.Icon,{name:o?"success":"error"})," ",o?"Success":"Error: "+s.reason]})}]}})})});return[{label:"View details",onClick:()=>{n(r)}}]}}export{u};
