import{j as e}from"./index-C88DWJny.js";import{U as y}from"./UsedByRow-Cdbm4-ZF.js";const u=({storage:s})=>e.jsx("table",{children:e.jsxs("tbody",{children:[e.jsx(y,{entityType:"instance",usedBy:s.used_by}),e.jsx(y,{entityType:"profile",usedBy:s.used_by}),e.jsx(y,{entityType:"image",usedBy:s.used_by}),e.jsx(y,{entityType:"snapshot",usedBy:s.used_by}),e.jsx(y,{entityType:"volume",usedBy:s.used_by}),e.jsx(y,{entityType:"bucket",usedBy:s.used_by})]})});export{u as S};
