import{d as r,s as c,j as p,au as l}from"./index-C88DWJny.js";const g=({tabs:e,activeTab:t,tabUrl:i})=>{const a=r.useNotify(),u=c();return p.jsx(r.Tabs,{links:e.map(s=>{if(typeof s!="string")return s;const n=l(s),o=s===e[0]?i:`${i}/${n}`;return{label:s,id:n,active:n===t||s===e[0]&&!t,onClick:f=>{f.preventDefault(),a.clear(),u(o)},href:o}})})};export{g as T};
