import{a3 as n,m as o,j as d,d as i}from"./index-C88DWJny.js";const C=({label:t,disabled:l,disableReason:e,...s})=>{const a=n(),{data:u=[],isLoading:m}=o();return a?d.jsx(i.Select,{...s,label:t??"Cluster member",options:u.map(r=>({label:r.server_name,value:r.server_name})),disabled:l||m||!!e,help:e??s.help}):null};export{C};
