import{j as s,d,r as l,au as e,K as m}from"./index-C88DWJny.js";const u=({active:t,setActive:n,label:i,disableReason:a,hasError:o,isBold:c})=>{const r=c?"strong":l.Fragment;return a?s.jsx("li",{className:"p-side-navigation__item",children:s.jsx(d.Button,{className:"p-side-navigation__link p-button--base",disabled:!0,title:a,children:s.jsx(r,{children:i})})}):s.jsx("li",{className:m("p-side-navigation__item",{"has-error":o}),children:s.jsx("a",{className:"p-side-navigation__link",onClick:()=>{n(i)},"aria-current":e(i)===e(t)?"page":void 0,children:s.jsx(r,{children:i})})})};export{u as F};
