import{r as e,j as s,d as l}from"./index-C88DWJny.js";const p=5,i=({items:t,displayCount:a=p})=>{const[n,r]=e.useState(a);return s.jsxs(s.Fragment,{children:[t.slice(0,n),n<t.length&&s.jsx(l.Button,{appearance:"link",className:"u-no-margin--bottom",small:!0,onClick:o=>{r(t.length),o.stopPropagation()},children:"Show all"})]})};export{i as E};
