define("vs/monaco.contribution-qLAYrEOP",["require","exports","./editor.api-CalNCsUg"],(function(p,n,f){"use strict";class D{constructor(t,c,s){this._onDidChange=new f.Emitter,this._languageId=t,this.setOptions(c),this.setModeConfiguration(s)}get onDidChange(){return this._onDidChange.event}get languageId(){return this._languageId}get options(){return this._options}get modeConfiguration(){return this._modeConfiguration}setOptions(t){this._options=t||Object.create(null),this._onDidChange.fire(this)}setModeConfiguration(t){this._modeConfiguration=t||Object.create(null),this._onDidChange.fire(this)}}const r={format:{tabSize:4,insertSpaces:!1,wrapLineLength:120,unformatted:'default": "a, abbr, acronym, b, bdo, big, br, button, cite, code, dfn, em, i, img, input, kbd, label, map, object, q, samp, select, small, span, strong, sub, sup, textarea, tt, var',contentUnformatted:"pre",indentInnerHtml:!1,preserveNewLines:!0,maxPreserveNewLines:void 0,indentHandlebars:!1,endWithNewline:!1,extraLiners:"head, body, /html",wrapAttributes:"auto"},suggest:{},data:{useDefaultDataProvider:!0}};function i(e){return{completionItems:!0,hovers:!0,documentSymbols:!0,links:!0,documentHighlights:!0,rename:!0,colors:!0,foldingRanges:!0,selectionRanges:!0,diagnostics:e===a,documentFormattingEdits:e===a,documentRangeFormattingEdits:e===a}}const a="html",m="handlebars",h="razor",u=o(a,r,i(a)),b=u.defaults,g=o(m,r,i(m)),L=g.defaults,l=o(h,r,i(h)),v=l.defaults;function _(){return new Promise((e,t)=>p(["./htmlMode-Bz67EXwp"],e,t))}function o(e,t=r,c=i(e)){const s=new D(e,t,c);let d;const C=f.languages.onLanguage(e,async()=>{d=(await _()).setupMode(s)});return{defaults:s,dispose(){C.dispose(),d?.dispose(),d=void 0}}}const S=Object.freeze(Object.defineProperty({__proto__:null,handlebarDefaults:L,handlebarLanguageService:g,htmlDefaults:b,htmlLanguageService:u,razorDefaults:v,razorLanguageService:l,registerHTMLLanguageService:o},Symbol.toStringTag,{value:"Module"}));n.handlebarDefaults=L,n.handlebarLanguageService=g,n.htmlDefaults=b,n.htmlLanguageService=u,n.monaco_contribution=S,n.razorDefaults=v,n.razorLanguageService=l,n.registerHTMLLanguageService=o}));
