const i=e=>{document.getElementById(e)?.scrollIntoView({inline:"nearest",block:"nearest"})},m=(e,t)=>{const s=t?t.scrollTop:0,l=t?t.offsetTop:0;let o=e[0];for(const n of e){if((document.getElementById(n.toLowerCase())?.offsetTop??0)>s+l+25)return o;o=n}return o};export{m as g,i as s};
