const e={ARCH_32BIT_INTEL_X86:"i686",ARCH_64BIT_INTEL_X86:"x86_64",ARCH_32BIT_ARMV6_LITTLE_ENDIAN:"armv6l",ARCH_32BIT_ARMV7_LITTLE_ENDIAN:"armv7l",ARCH_32BIT_ARMV8_LITTLE_ENDIAN:"armv8l",ARCH_64BIT_ARMV8_LITTLE_ENDIAN:"aarch64",ARCH_32BIT_POWERPC_BIG_ENDIAN:"ppc",ARCH_64BIT_POWERPC_BIG_ENDIAN:"ppc64",ARCH_64BIT_POWERPC_LITTLE_ENDIAN:"ppc64le",ARCH_64BIT_S390_BIG_ENDIAN:"s390x",ARCH_32BIT_MIPS:"mips",ARCH_64BIT_MIPS:"mips64",ARCH_32BIT_RISCV_LITTLE_ENDIAN:"riscv32",ARCH_64BIT_RISCV_LITTLE_ENDIAN:"riscv64"},T={ARCH_32BIT_INTEL_X86:["i386","i586","386","x86","generic_32"],ARCH_64BIT_INTEL_X86:["amd64","generic_64"],ARCH_32BIT_ARMV6_LITTLE_ENDIAN:["armel","arm"],ARCH_32BIT_ARMV7_LITTLE_ENDIAN:["armhf","armhfp","armv7a_hardfp","armv7","armv7a_vfpv3_hardfp"],ARCH_32BIT_ARMV8_LITTLE_ENDIAN:[],ARCH_64BIT_ARMV8_LITTLE_ENDIAN:["arm64","arm64_generic"],ARCH_32BIT_POWERPC_BIG_ENDIAN:["powerpc"],ARCH_64BIT_POWERPC_BIG_ENDIAN:["powerpc64","ppc64"],ARCH_64BIT_POWERPC_LITTLE_ENDIAN:["ppc64el"],ARCH_32BIT_MIPS:["mipsel","mipsle"],ARCH_64BIT_MIPS:["mips64el","mips64le"],ARCH_32BIT_RISCV_LITTLE_ENDIAN:[],ARCH_64BIT_RISCV_LITTLE_ENDIAN:[]},s=I=>{const E=[],_=Object.keys(e);return I.map(A=>{const R=_.find(N=>e[N]===A);R&&R in T&&E.push(...T[R]),E.push(A)}),E},C=I=>{const _=Object.keys(e).find(A=>e[A]===I);return _&&_ in T&&T[_].length>0?T[_][0]:I},a=I=>{const _=Object.keys(T).find(A=>T[A].includes(I));return _&&_ in e?e[_]:I};export{C as a,a as b,s as g};
