import{eF as a}from"./index-C88DWJny.js";const u=(t,e)=>`${t}T${e}`,c=()=>["valid","Invalid date format",(t,e)=>t?new Date(t).toString()!=="Invalid Date":!e.parent.expirationTime],d=()=>["future","The date must be in the future",t=>{if(!t)return!0;const e=new Date(t).getTime(),r=new Date(a()).getTime();return e>=r}],f=()=>["valid","Invalid time format",(t,e)=>{if(!t)return!e.parent.expirationDate;const[r,i]=t.split(":"),n=new Date;return n.setHours(+r),n.setMinutes(+i),n.toString()!=="Invalid Date"}],m=t=>s("restricted.snapshots",t),l=t=>s("restricted.backups",t),s=(t,e)=>!e||e.config.restricted!=="true"?!1:!e.config[t]||e.config[t]==="block";export{c as a,d as b,l as c,u as g,m as i,f as t};
