import{cW as d,j as s}from"./index-C88DWJny.js";import{F as n}from"./FormMenuItem-f1QSo43l.js";const h="Connections",j="General",l="Bridge",r="DNS",c="IPv4",i="IPv6",u="OVN",O="YAML configuration",b=({active:N,setActive:m,formik:o,availableSections:t})=>{const e={active:N,setActive:m},x=o.values.name.length>0,I=d.includes(o.values.networkType)&&!o.values.parent&&o.values.isCreating,a=x?I?"Please select a parent network to enable this section":"":"Please enter a network name to enable this section";return s.jsx("nav",{"aria-label":"Network form navigation",className:"toc-tree",children:s.jsxs("ul",{children:[s.jsx(n,{label:j,...e}),t.includes(l)&&s.jsx(n,{label:l,...e,disableReason:a}),t.includes(c)&&s.jsx(n,{label:c,...e,disableReason:a}),t.includes(i)&&s.jsx(n,{label:i,...e,disableReason:a}),t.includes(r)&&s.jsx(n,{label:r,...e,disableReason:a}),t.includes(u)&&s.jsx(n,{label:u,...e,disableReason:a})]})})};export{l as B,h as C,r as D,j as G,c as I,b as N,u as O,O as Y,i as a};
