import{j as o,K as s}from"./index-C88DWJny.js";const a=({children:t,isAlignRight:r=!0})=>o.jsx("div",{className:"p-bottom-controls form-footer",id:"form-footer",children:o.jsx("footer",{className:s("bottom-btns",{"u-align--right":r}),children:t})});export{a as F};
