import{a3 as l,m,p as d,aP as t,q as c,e3 as i,eO as b}from"./index-C88DWJny.js";const f=s=>{const e=l(),{data:a=[]}=m(),{canViewResources:r}=d(),n=t({queryKey:[c.resources],queryFn:async()=>i(),enabled:r()&&!e}),u=a.filter(y=>!s||y.server_name===s),o=t({queryKey:[c.resources,u],queryFn:async()=>b(u),enabled:r()&&e});return e?o:n};export{f as u};
