import{j as a}from"./index-C88DWJny.js";const r=({children:e})=>a.jsx("div",{className:"page-header__left",children:e}),t=({children:e})=>a.jsx("h1",{className:"p-heading--4 u-no-margin--bottom",children:e}),n=({children:e})=>a.jsx("div",{className:"page-header__search margin-right--large u-no-margin--bottom",children:e}),o=({children:e})=>a.jsx("div",{className:"page-header__base-actions",children:e}),c=({children:e})=>a.jsx("div",{className:"p-panel__header page-header",children:e}),s=c;s.Left=r;s.Title=t;s.Search=n;s.BaseActions=o;export{s as P};
